@@ -3,7 +3,13 @@
 from __future__ import annotations
 
 import configparser
-from importlib import metadata, resources
+import sys
+from importlib import metadata
+
+if sys.version_info < (3, 9, 0):
+	import importlib_resources as ilr
+else:
+	import importlib.resources as ilr
 from pathlib import Path
 from typing import Any, cast
 
@@ -33,7 +39,7 @@ def getPackageInfoLocal(requirement: str) -> PackageInfo:
 		version = pkgMetadata.get("Version", UNKNOWN)
 		size = 0
 		try:
-			packagePath = resources.files(requirement)
+			packagePath = ilr.files(requirement)
 			size = getModuleSize(cast(Path, packagePath), name)
 		except TypeError:
 			pass
@@ -85,6 +91,8 @@ def licenseFromClassifierlist(classifiers: list[str]) -> str:
 	Returns:
 		str: the license name
 	"""
+	if not classifiers:
+		return UNKNOWN
 	licenses = []
 	for val in classifiers:
 		if val.startswith("License"):
@@ -167,9 +175,15 @@ def getModuleSize(path: Path, name: str) -> int:
 	Returns:
 		int: size in bytes
 	"""
-	size = sum(
-		f.stat().st_size for f in path.glob("**/*") if f.is_file() and "__pycache__" not in str(f)
-	)
+	size = 0
+	try:
+		size = sum(
+			f.stat().st_size
+			for f in path.glob("**/*")
+			if f.is_file() and "__pycache__" not in str(f)
+		)
+	except AttributeError:
+		pass
 	if size > 0:
 		return size
 	request = requests.get(f"https://pypi.org/pypi/{name}/json", timeout=60)
